@@ -81,8 +81,6 @@ class SeleniumDownloaderMiddleware:
         return middleware
 
     def process_request(self, request, spider):
-        self.driver.get(request.url)
-
         for cookie_name, cookie_value in request.cookies.items():
             self.driver.add_cookie(
                 {
@@ -91,6 +89,8 @@ class SeleniumDownloaderMiddleware:
                 }
             )
 
+        self.driver.get(request.url)
+
         if "wait_text_to_be_present" in request.meta:
             try:
                 if isinstance(request.meta['wait_text_to_be_present'], dict):
@@ -131,6 +131,15 @@ class SeleniumDownloaderMiddleware:
                 return Response('', status=504)
             del request.meta['wait_to_be_clickable']
 
+        if "post_load_script" in request.meta:
+            try:
+                scriptCommands = request.meta['post_load_script']
+                for scriptCommand in scriptCommands:
+                    exec(scriptCommand)
+            except:
+                return Response('', status=504)
+            del request.meta['post_load_script']
+
         body = str.encode(self.driver.page_source)
 
         # Expose the driver via the "meta" attribute
